@@ -15,7 +15,6 @@ from functools import partial
 from bypy.constants import LIBDIR, OUTPUT_DIR, PREFIX, python_major_minor_version
 from bypy.constants import SRC as CALIBRE_DIR
 from bypy.freeze import extract_extension_modules, fix_pycryptodome, freeze_python, is_package_dir, path_to_freeze_dir
-from bypy.pkgs.piper import copy_piper_dir
 from bypy.utils import create_job, get_dll_path, mkdtemp, parallel_build, py_compile, run, walk
 
 j = os.path.join
@@ -41,8 +40,8 @@ def binary_includes():
             get_dll_path,
             ('usb-1.0 mtp expat sqlite3 ffi z lzma openjp2 poppler dbus-1 iconv xml2 xslt jpeg png16'
              ' webp webpmux webpdemux sharpyuv exslt ncursesw readline chm hunspell-1.7 hyphen'
-             ' icudata icui18n icuuc icuio stemmer gcrypt gpg-error uchardet graphite2'
-             ' brotlicommon brotlidec brotlienc zstd podofo ssl crypto deflate tiff'
+             ' icudata icui18n icuuc icuio stemmer gcrypt gpg-error uchardet graphite2 espeak-ng'
+             ' brotlicommon brotlidec brotlienc zstd podofo ssl crypto deflate tiff onnxruntime'
              ' gobject-2.0 glib-2.0 gthread-2.0 gmodule-2.0 gio-2.0 dbus-glib-1').split()
         )) + [
             # debian/ubuntu for for some typical stupid reason use libpcre.so.3
@@ -112,11 +111,6 @@ def import_site_packages(srcdir, dest):
             shutil.copytree(f, j(dest, x), ignore=ignore_in_lib)
 
 
-def copy_piper(env):
-    print('Copying piper...')
-    copy_piper_dir(PREFIX, env.bin_dir)
-
-
 def copy_libs(env):
     print('Copying libs...')
 
@@ -138,6 +132,9 @@ def copy_libs(env):
     dest = j(env.lib_dir, '..', 'libexec')
     os.mkdir(dest)
     shutil.copy2(os.path.join(QT_PREFIX, 'libexec', 'QtWebEngineProcess'), dest)
+    dest = j(env.lib_dir, '..', 'share')
+    os.mkdir(dest)
+    shutil.copytree(os.path.join(PREFIX, 'share/espeak-ng-data'), os.path.join(dest, 'espeak-ng-data'))
 
 
 def copy_python(env, ext_dir):
@@ -262,7 +259,7 @@ def strip_files(files, argv_max=(256 * 1024)):
 
 
 def strip_binaries(env):
-    files = {j(env.bin_dir, x) for x in os.listdir(env.bin_dir) if x != 'piper'} | {
+    files = {j(env.bin_dir, x) for x in os.listdir(env.bin_dir)} | {
         x for x in {
             j(os.path.dirname(env.bin_dir), x) for x in os.listdir(env.bin_dir)} if os.path.exists(x)}
     for x in walk(env.lib_dir):
@@ -314,7 +311,6 @@ def main():
     env = Env()
     copy_libs(env)
     copy_python(env, ext_dir)
-    copy_piper(env)
     build_launchers(env)
     if not args.skip_tests:
         run_tests(j(env.base, 'calibre-debug'), env.base)
