@@ -8,6 +8,7 @@ __docformat__ = 'restructuredtext en'
 import errno
 import glob
 import hashlib
+import inspect
 import json
 import os
 import re
@@ -19,7 +20,7 @@ import tempfile
 import textwrap
 import time
 from collections import defaultdict
-from functools import partial
+from functools import lru_cache, partial
 from locale import normalize as normalize_locale
 
 from polyglot.builtins import codepoint_to_chr, iteritems
@@ -28,6 +29,20 @@ from setup.iso_codes import iso_data
 from setup.parallel_build import batched_parallel_jobs
 
 
+def serialize_msgid(text):
+    '''Serialize a string in the format used by msgid in GNU POT files.'''
+    if not text:
+        return 'msgid ""\n'
+    # Escape backslashes and quotes
+    escaped = text.replace('\\', r'\\').replace('"', r'\"')
+    ans = ['msgid ""']
+    lines = escaped.splitlines()
+    for line in lines:
+        trailer = '"' if line is lines[-1] else r'\n"'
+        ans.append(f'"{line}{trailer}')
+    return '\n'.join(ans)
+
+
 def qt_sources():
     qtdir = os.environ.get('QT_SRC', '/usr/src/qt6/qtbase')
     j = partial(os.path.join, qtdir)
@@ -39,6 +54,11 @@ def qt_sources():
     ]))
 
 
+@lru_cache(maxsize=2)
+def tx_exe():
+    return os.environ.get('TX', shutil.which('tx-cli') or shutil.which('tx') or 'tx')
+
+
 class POT(Command):  # {{{
 
     description = 'Update the .pot translation template and upload it'
@@ -49,7 +69,7 @@ class POT(Command):  # {{{
         kw['cwd'] = kw.get('cwd', self.TRANSLATIONS)
         if hasattr(cmd, 'format'):
             cmd = shlex.split(cmd)
-        cmd = [os.environ.get('TX', 'tx')] + cmd
+        cmd = [tx_exe()] + cmd
         self.info(' '.join(cmd))
         return subprocess.check_call(cmd, **kw)
 
@@ -71,6 +91,20 @@ class POT(Command):  # {{{
                     ans.append(self.a(self.j(root, name)))
         return ans
 
+    def get_ffml_docs(self):
+        from calibre.gui2.dialogs.template_general_info import ffml_doc, general_doc
+        from calibre.utils.formatter_functions import _formatter_builtins as b
+        ans = []
+        for ff in b:
+            lnum = inspect.getsourcelines(ff.__doc__getter__)[1]
+            text = ff.__doc__getter__().msgid
+            ans.append(f'#: src/calibre/utils/formatter_function.py:{lnum}\n' + serialize_msgid(text) + '\nmsgstr ""\n\n')
+        for ff in (ffml_doc, general_doc):
+            lnum = inspect.getsourcelines(ff)[1]
+            text = ff().msgid
+            ans.append(f'#: src/calibre/gui2/dialogs/template_general_info.py:{lnum}\n' + serialize_msgid(text) + '\nmsgstr ""\n\n')
+        return ''.join(ans)
+
     def get_tweaks_docs(self):
         path = self.a(self.j(self.SRC, '..', 'resources', 'default_tweaks.py'))
         with open(path, 'rb') as f:
@@ -218,12 +252,12 @@ class POT(Command):  # {{{
                 '--from-code=UTF-8', '--sort-by-file', '--omit-header',
                                    '--no-wrap', '-kQT_TRANSLATE_NOOP:2', '-ktr', '-ktranslate:2',
                 ] + qt_inputs)
-
             with open(out.name, 'rb') as f:
                 src = f.read().decode('utf-8')
             os.remove(out.name)
             src = pot_header + '\n' + src
             src += '\n\n' + self.get_tweaks_docs()
+            src += '\n\n' + self.get_ffml_docs()
             bdir = os.path.join(self.TRANSLATIONS, __appname__)
             if not os.path.exists(bdir):
                 os.makedirs(bdir)
@@ -286,7 +320,7 @@ class Translations(POT):  # {{{
 
     def is_po_file_ok(self, x):
         bname = os.path.splitext(os.path.basename(x))[0]
-        # sr@latin.po is identical to sr.po. And we dont support country
+        # sr@latin.po is identical to sr.po. And we don't support country
         # specific variants except for a few.
         if '_' in bname:
             return bname.partition('_')[0] in ('pt', 'zh', 'bn')
@@ -511,7 +545,7 @@ class Translations(POT):  # {{{
             locale = fmap[src]
             trans, untrans = data['translated'], data['untranslated']
             total = trans + untrans
-            stats[locale] = int(round(100 * trans / total))
+            stats[locale] = round(100 * trans / total)
 
         with TemporaryDirectory() as tdir, ZipFile(self.j(srcbase, 'locales.zip'), 'w', ZIP_STORED) as zf:
             for f in os.listdir(srcbase):
