@@ -11,7 +11,7 @@ from functools import lru_cache
 from polyglot.builtins import environ_item, hasenv
 
 __appname__   = 'calibre'
-numeric_version = (8, 6, 0)
+numeric_version = (8, 8, 0)
 __version__   = '.'.join(map(str, numeric_version))
 git_version   = None
 __author__    = 'Kovid Goyal <kovid@kovidgoyal.net>'
@@ -54,7 +54,7 @@ TOC_DIALOG_APP_UID = 'com.calibre-ebook.toc-editor'
 try:
     preferred_encoding = locale.getpreferredencoding()
     codecs.lookup(preferred_encoding)
-except:
+except Exception:
     preferred_encoding = 'utf-8'
 
 dark_link_color = '#6cb4ee'
@@ -258,6 +258,7 @@ class ExtensionsImporter:
             'rcc_backend',
             'icu',
             'speedup',
+            'piper',
             'html_as_json',
             'fast_css_transform',
             'fast_html_entities',
@@ -391,7 +392,7 @@ else:
     config_dir = os.path.join(bdir, 'calibre')
     try:
         os.makedirs(config_dir, mode=CONFIG_DIR_MODE)
-    except:
+    except Exception:
         pass
     if not os.path.exists(config_dir) or \
             not os.access(config_dir, os.W_OK) or not \
@@ -405,7 +406,7 @@ else:
             try:
                 import shutil
                 shutil.rmtree(config_dir)
-            except:
+            except Exception:
                 pass
         atexit.register(cleanup_cdir)
 # }}}
@@ -506,19 +507,3 @@ def bundled_binaries_dir() -> str:
     if (islinux or isbsd) and getattr(sys, 'frozen', False):
         return os.path.join(sys.executables_location, 'bin')
     return ''
-
-
-@lru_cache(2)
-def piper_cmdline() -> tuple[str, ...]:
-    ext = '.exe' if iswindows else ''
-    if bbd := bundled_binaries_dir():
-        if ismacos:
-            return (os.path.join(sys.frameworks_dir, 'piper', 'piper'),)
-        return (os.path.join(bbd, 'piper', 'piper' + ext),)
-    if pd := os.environ.get('PIPER_TTS_DIR'):
-        return (os.path.join(pd, 'piper' + ext),)
-    import shutil
-    exe = shutil.which('piper-tts')
-    if exe:
-        return (exe,)
-    return ()
