@@ -88,7 +88,7 @@ def option_recommendation_to_cli_option(add_option, rec):
     switches = ['-'+opt.short_switch] if opt.short_switch else []
     switches.append('--'+opt.long_switch)
     attrs = dict(dest=opt.name, help=opt.help,
-                     choices=opt.choices, default=rec.recommended_value)
+                 choices=opt.choices, default=rec.recommended_value)
     if isinstance(rec.recommended_value, bool):
         attrs['action'] = 'store_false' if rec.recommended_value else \
                           'store_true'
@@ -151,10 +151,10 @@ def recipe_test(option, opt_str, value, parser):
 
     for arg in parser.rargs:
         # stop on --foo like options
-        if arg[:2] == "--":
+        if arg[:2] == '--':
             break
         # stop on -a, but not on -3 or -3.0
-        if arg[:1] == "-" and len(arg) > 1 and not floatable(arg):
+        if arg[:1] == '-' and len(arg) > 1 and not floatable(arg):
             break
         try:
             value.append(int(arg))
@@ -198,13 +198,13 @@ def add_input_output_options(parser, plumber):
 
 def add_pipeline_options(parser, plumber):
     groups = OrderedDict((
-              ('' , ('',
+              ('', ('',
                     [
                      'input_profile',
                      'output_profile',
                      ]
                     )),
-              (_('LOOK AND FEEL') , (
+              (_('LOOK AND FEEL'), (
                   _('Options to control the look and feel of the output'),
                   [
                       'base_font_size', 'disable_font_rescaling',
@@ -223,7 +223,7 @@ def add_pipeline_options(parser, plumber):
                   ]
                   )),
 
-              (_('HEURISTIC PROCESSING') , (
+              (_('HEURISTIC PROCESSING'), (
                   _('Modify the document text and structure using common'
                      ' patterns. Disabled by default. Use %(en)s to enable. '
                      ' Individual actions can be disabled with the %(dis)s options.')
@@ -231,7 +231,7 @@ def add_pipeline_options(parser, plumber):
                   ['enable_heuristics'] + HEURISTIC_OPTIONS
                   )),
 
-              (_('SEARCH AND REPLACE') , (
+              (_('SEARCH AND REPLACE'), (
                  _('Modify the document text and structure using user defined patterns.'),
                  [
                      'sr1_search', 'sr1_replace',
@@ -241,7 +241,7 @@ def add_pipeline_options(parser, plumber):
                  ]
               )),
 
-              (_('STRUCTURE DETECTION') , (
+              (_('STRUCTURE DETECTION'), (
                   _('Control auto-detection of document structure.'),
                   [
                       'chapter', 'chapter_mark',
@@ -251,7 +251,7 @@ def add_pipeline_options(parser, plumber):
                   ]
                   )),
 
-              (_('TABLE OF CONTENTS') , (
+              (_('TABLE OF CONTENTS'), (
                   _('Control the automatic generation of a Table of Contents. By '
                   'default, if the source file has a Table of Contents, it will '
                   'be used in preference to the automatically generated one.'),
@@ -262,7 +262,7 @@ def add_pipeline_options(parser, plumber):
                   ]
                   )),
 
-              (_('METADATA') , (_('Options to set metadata in the output'),
+              (_('METADATA'), (_('Options to set metadata in the output'),
                             plumber.metadata_option_names + ['read_metadata_from_opf'],
                             )),
               (_('DEBUG'), (_('Options to help with debugging the conversion'),
@@ -302,7 +302,7 @@ class ProgressBar:
     def __call__(self, frac, msg=''):
         if msg:
             percent = int(frac*100)
-            self.log('%d%% %s'%(percent, msg))
+            self.log(f'{percent}% {msg}')
 
 
 def create_option_parser(args, log):
@@ -318,9 +318,9 @@ def create_option_parser(args, log):
         for title in titles:
             try:
                 log('\t'+title)
-            except:
+            except Exception:
                 log('\t'+repr(title))
-        log('%d recipes available'%len(titles))
+        log(f'{len(titles)} recipes available')
         raise SystemExit(0)
 
     parser = option_parser()
@@ -347,7 +347,7 @@ def create_option_parser(args, log):
 
 
 def abspath(x):
-    if x.startswith('http:') or x.startswith('https:'):
+    if x.startswith(('http:', 'https:')):
         return x
     return os.path.abspath(os.path.expanduser(x))
 
@@ -370,9 +370,8 @@ def read_sr_patterns(path, log=None):
             line = line.replace('\ue123', '\n')
             try:
                 re.compile(line)
-            except:
-                msg = 'Invalid regular expression: %r from file: %r'%(
-                        line, path)
+            except Exception:
+                msg = f'Invalid regular expression: {line!r} from file: {path!r}'
                 if log is not None:
                     log.error(msg)
                     raise SystemExit(1)
