@@ -7,7 +7,8 @@ import re
 import struct
 import zlib
 
-from calibre import entity_to_unicode, prepare_string_for_xml
+from calibre import prepare_string_for_xml
+from calibre.ebooks.html_entities import entity_to_unicode_in_python
 from calibre.ebooks.lrf import PRS500_PROFILE, LRFParseError
 from calibre.ebooks.lrf.tags import Tag
 
@@ -74,7 +75,7 @@ class LRFObject:
             self.handle_tag(tag, stream)
 
     def parse_bg_image(self, tag, f):
-        self.bg_image_mode, self.bg_image_id = struct.unpack("<HI", tag.contents)
+        self.bg_image_mode, self.bg_image_id = struct.unpack('<HI', tag.contents)
 
     def handle_tag(self, tag, stream, tag_map=None):
         if tag_map is None:
@@ -85,7 +86,7 @@ class LRFObject:
             if h[1] != '' and h[0] != '':
                 setattr(self, h[0], val)
         else:
-            raise LRFParseError(f"Unknown tag in {self.__class__.__name__}: {str(tag)}")
+            raise LRFParseError(f'Unknown tag in {self.__class__.__name__}: {tag}')
 
     def __iter__(self):
         yield from range(0)
@@ -128,7 +129,7 @@ class LRFContentObject(LRFObject):
                 func, args = action[0], (action[1],)
             getattr(self, func)(tag, *args)
         else:
-            raise LRFParseError(f"Unknown tag in {self.__class__.__name__}: {str(tag)}")
+            raise LRFParseError(f'Unknown tag in {self.__class__.__name__}: {tag}')
 
     def __iter__(self):
         yield from self._contents
@@ -172,12 +173,12 @@ class LRFStream(LRFObject):
                 l = 0x400
             self.stream = self.descramble_buffer(self.stream, l, key)
         if self.stream_flags & 0x100 !=0:
-            decomp_size = struct.unpack("<I", self.stream[:4])[0]
+            decomp_size = struct.unpack('<I', self.stream[:4])[0]
             self.stream = zlib.decompress(self.stream[4:])
             if len(self.stream) != decomp_size:
-                raise LRFParseError("Stream decompressed size is wrong!")
+                raise LRFParseError('Stream decompressed size is wrong!')
         if stream.read(2) != b'\x06\xF5':
-            print("Warning: corrupted end-of-stream tag at %08X; skipping it"%(stream.tell()-2))
+            print(f'Warning: corrupted end-of-stream tag at {stream.tell()-2:08X}; skipping it')
         self.end_stream(None, None)
 
 
@@ -199,11 +200,11 @@ class StyleObject:
         for h in self.tag_map.values():
             attr = h[0]
             if hasattr(self, attr):
-                s += '%s="%s" '%(attr, getattr(self, attr))
+                s += f'{attr}="{getattr(self, attr)}" '
         return s
 
     def __str__(self):
-        s = '<%s objid="%s" stylelabel="%s" '%(self.__class__.__name__.replace('Attr', 'Style'), self.id, self.id)
+        s = '<{} objid="{}" stylelabel="{}" '.format(self.__class__.__name__.replace('Attr', 'Style'), self.id, self.id)
         s += self._tags_to_xml()
         s += '/>\n'
         return s
@@ -236,7 +237,7 @@ class PageAttr(StyleObject, LRFObject):
         0xF52B: ['pageposition', 'W', {0: 'any', 1:'upper', 2: 'lower'}],
         0xF52A: ['setemptyview', 'W', {1: 'show', 0: 'empty'}],
         0xF5DA: ['setwaitprop', 'W', {1: 'replay', 2: 'noreplay'}],
-        0xF529: ['', "parse_bg_image"],
+        0xF529: ['', 'parse_bg_image'],
       }
     tag_map.update(LRFObject.tag_map)
 
@@ -251,7 +252,7 @@ class Color:
         self.a, self.r, self.g, self.b = val & 0xFF, (val>>8)&0xFF, (val>>16)&0xFF, (val>>24)&0xFF
 
     def __str__(self):
-        return '0x%02x%02x%02x%02x'%(self.a, self.r, self.g, self.b)
+        return f'0x{self.a:02x}{self.r:02x}{self.g:02x}{self.b:02x}'
 
     def __len__(self):
         return 4
@@ -260,7 +261,7 @@ class Color:
         return (self.r, self.g, self.b, 0xff-self.a)[i]  # In Qt 0xff is opaque while in LRS 0x00 is opaque
 
     def to_html(self):
-        return 'rgb(%d, %d, %d)'%(self.r, self.g, self.b)
+        return f'rgb({self.r}, {self.g}, {self.b})'
 
 
 class EmptyPageElement:
@@ -279,8 +280,7 @@ class PageDiv(EmptyPageElement):
         self.linecolor = Color(linecolor)
 
     def __str__(self):
-        return '\n<PageDiv pain="%s" spacesize="%s" linewidth="%s" linecolor="%s" />\n'%\
-                (self.pain, self.spacesize, self.linewidth, self.color)
+        return f'\n<PageDiv pain="{self.pain}" spacesize="{self.spacesize}" linewidth="{self.linewidth}" linecolor="{self.color}" />\n'
 
 
 class RuledLine(EmptyPageElement):
@@ -294,8 +294,7 @@ class RuledLine(EmptyPageElement):
         self.id = -1
 
     def __str__(self):
-        return '\n<RuledLine linelength="%s" linetype="%s" linewidth="%s" linecolor="%s" />\n'%\
-                (self.linelength, self.linetype, self.linewidth, self.linecolor)
+        return f'\n<RuledLine linelength="{self.linelength}" linetype="{self.linetype}" linewidth="{self.linewidth}" linecolor="{self.linecolor}" />\n'
 
 
 class Wait(EmptyPageElement):
@@ -304,7 +303,7 @@ class Wait(EmptyPageElement):
         self.time = time
 
     def __str__(self):
-        return '\n<Wait time="%d" />\n'%(self.time)
+        return f'\n<Wait time="{self.time}" />\n'
 
 
 class Locate(EmptyPageElement):
@@ -315,7 +314,7 @@ class Locate(EmptyPageElement):
         self.pos = self.pos_map[pos]
 
     def __str__(self):
-        return '\n<Locate pos="%s" />\n'%(self.pos)
+        return f'\n<Locate pos="{self.pos}" />\n'
 
 
 class BlockSpace(EmptyPageElement):
@@ -324,8 +323,7 @@ class BlockSpace(EmptyPageElement):
         self.xspace, self.yspace = xspace, yspace
 
     def __str__(self):
-        return '\n<BlockSpace xspace="%d" yspace="%d" />\n'%\
-                (self.xspace, self.yspace)
+        return f'\n<BlockSpace xspace="{self.xspace}" yspace="{self.yspace}" />\n'
 
 
 class Page(LRFStream):
@@ -337,11 +335,11 @@ class Page(LRFStream):
       }
     tag_map.update(PageAttr.tag_map)
     tag_map.update(LRFStream.tag_map)
-    style = property(fget=lambda self : self._document.objects[self.style_id])
-    evenheader = property(fget=lambda self : self._document.objects[self.style.evenheaderid])
-    evenfooter = property(fget=lambda self : self._document.objects[self.style.evenfooterid])
-    oddheader  = property(fget=lambda self : self._document.objects[self.style.oddheaderid])
-    oddfooter  = property(fget=lambda self : self._document.objects[self.style.oddfooterid])
+    style = property(fget=lambda self: self._document.objects[self.style_id])
+    evenheader = property(fget=lambda self: self._document.objects[self.style.evenheaderid])
+    evenfooter = property(fget=lambda self: self._document.objects[self.style.evenfooterid])
+    oddheader  = property(fget=lambda self: self._document.objects[self.style.oddheaderid])
+    oddfooter  = property(fget=lambda self: self._document.objects[self.style.oddfooterid])
 
     class Content(LRFContentObject):
         tag_map = {
@@ -365,7 +363,7 @@ class Page(LRFStream):
 
         def page_div(self, tag):
             self.close_blockspace()
-            pars = struct.unpack("<HIHI", tag.contents)
+            pars = struct.unpack('<HIHI', tag.contents)
             self._contents.append(PageDiv(*pars))
 
         def x_space(self, tag):
@@ -382,7 +380,7 @@ class Page(LRFStream):
 
         def ruled_line(self, tag):
             self.close_blockspace()
-            pars = struct.unpack("<HHHI", tag.contents)
+            pars = struct.unpack('<HHHI', tag.contents)
             self._contents.append(RuledLine(*pars))
 
         def wait(self, tag):
@@ -421,7 +419,7 @@ class Page(LRFStream):
         yield from self.content
 
     def __str__(self):
-        s = '\n<Page pagestyle="%d" objid="%d">\n'%(self.style_id, self.id)
+        s = f'\n<Page pagestyle="{self.style_id}" objid="{self.id}">\n'
         for i in self:
             s += str(i)
         s += '\n</Page>\n'
@@ -439,12 +437,12 @@ class BlockAttr(StyleObject, LRFObject):
         0xF531: ['blockwidth', 'W'],
         0xF532: ['blockheight', 'W'],
         0xF533: ['blockrule', 'W', {
-            0x14: "horz-fixed",
-            0x12: "horz-adjustable",
-            0x41: "vert-fixed",
-            0x21: "vert-adjustable",
-            0x44: "block-fixed",
-            0x22: "block-adjustable"}],
+            0x14: 'horz-fixed',
+            0x12: 'horz-adjustable',
+            0x41: 'vert-fixed',
+            0x21: 'vert-adjustable',
+            0x44: 'block-fixed',
+            0x22: 'block-adjustable'}],
         0xF534: ['bgcolor', 'D', Color],
         0xF535: ['layout', 'W', {0x41: 'TbRl', 0x34: 'LrTb'}],
         0xF536: ['framewidth', 'W'],
@@ -469,17 +467,17 @@ class BlockAttr(StyleObject, LRFObject):
 
         if hasattr(obj, 'sidemargin'):
             margin = str(obj.sidemargin) + 'px'
-            ans += item('margin-left: %(m)s; margin-right: %(m)s;'%dict(m=margin))
+            ans += item('margin-left: {m}; margin-right: {m};'.format(**dict(m=margin)))
         if hasattr(obj, 'topskip'):
-            ans += item('margin-top: %dpx;'%obj.topskip)
+            ans += item(f'margin-top: {obj.topskip}px;')
         if hasattr(obj, 'footskip'):
-            ans += item('margin-bottom: %dpx;'%obj.footskip)
+            ans += item(f'margin-bottom: {obj.footskip}px;')
         if hasattr(obj, 'framewidth'):
-            ans += item('border: solid %dpx'%obj.framewidth)
+            ans += item(f'border: solid {obj.framewidth}px')
         if hasattr(obj, 'framecolor') and obj.framecolor.a < 255:
-            ans += item('border-color: %s;'%obj.framecolor.to_html())
+            ans += item(f'border-color: {obj.framecolor.to_html()};')
         if hasattr(obj, 'bgcolor') and obj.bgcolor.a < 255:
-            ans += item('background-color: %s;'%obj.bgcolor.to_html())
+            ans += item(f'background-color: {obj.bgcolor.to_html()};')
 
         return ans
 
@@ -498,39 +496,39 @@ class TextCSS:
 
         fs = getattr(obj, 'fontsize', None)
         if fs is not None:
-            ans += item('font-size: %fpt;'%(int(fs)/10))
+            ans += item(f'font-size: {int(fs)/10:f}pt;')
         fw = getattr(obj, 'fontweight', None)
         if fw is not None:
-            ans += item('font-weight: %s;'%('bold' if int(fw) >= 700 else 'normal'))
+            ans += item('font-weight: {};'.format('bold' if int(fw) >= 700 else 'normal'))
         fn = getattr(obj, 'fontfacename', None)
         if fn is not None:
             fn = cls.FONT_MAP[fn]
-            ans += item('font-family: %s;'%fn)
+            ans += item(f'font-family: {fn};')
         fg = getattr(obj, 'textcolor', None)
         if fg is not None:
             fg = fg.to_html()
-            ans += item('color: %s;'%fg)
+            ans += item(f'color: {fg};')
         bg = getattr(obj, 'textbgcolor', None)
         if bg is not None:
             bg = bg.to_html()
-            ans += item('background-color: %s;'%bg)
+            ans += item(f'background-color: {bg};')
         al = getattr(obj, 'align', None)
         if al is not None:
             al = dict(head='left', center='center', foot='right')
-            ans += item('text-align: %s;'%al)
+            ans += item(f'text-align: {al};')
         lh = getattr(obj, 'linespace', None)
         if lh is not None:
-            ans += item('text-align: %fpt;'%(int(lh)/10))
+            ans += item(f'text-align: {int(lh)/10:f}pt;')
         pi = getattr(obj, 'parindent', None)
         if pi is not None:
-            ans += item('text-indent: %fpt;'%(int(pi)/10))
+            ans += item(f'text-indent: {int(pi)/10:f}pt;')
 
         return ans
 
 
 class TextAttr(StyleObject, LRFObject, TextCSS):
 
-    FONT_MAP = collections.defaultdict(lambda : 'serif')
+    FONT_MAP = collections.defaultdict(lambda: 'serif')
     for key, value in PRS500_PROFILE.default_fonts.items():
         FONT_MAP[value] = key
 
@@ -570,15 +568,15 @@ class Block(LRFStream, TextCSS):
     extra_attrs = [i[0] for i in BlockAttr.tag_map.values()]
     extra_attrs.extend([i[0] for i in TextAttr.tag_map.values()])
 
-    style = property(fget=lambda self : self._document.objects[self.style_id])
-    textstyle = property(fget=lambda self : self._document.objects[self.textstyle_id])
+    style = property(fget=lambda self: self._document.objects[self.style_id])
+    textstyle = property(fget=lambda self: self._document.objects[self.textstyle_id])
 
     def initialize(self):
         self.attrs = {}
         stream = io.BytesIO(self.stream)
         tag = Tag(stream)
         if tag.id != 0xF503:
-            raise LRFParseError("Bad block content")
+            raise LRFParseError('Bad block content')
         obj = self._document.objects[tag.dword]
         if isinstance(obj, SimpleText):
             self.name = 'SimpleTextBlock'
@@ -594,7 +592,7 @@ class Block(LRFStream, TextCSS):
         elif isinstance(obj, Button):
             self.name = 'ButtonBlock'
         else:
-            raise LRFParseError("Unexpected block type: "+obj.__class__.__name__)
+            raise LRFParseError('Unexpected block type: '+obj.__class__.__name__)
 
         self.content = obj
 
@@ -603,21 +601,21 @@ class Block(LRFStream, TextCSS):
                 self.attrs[attr] = getattr(self, attr)
 
     def __str__(self):
-        s = '\n<%s objid="%d" blockstyle="%s" '%(self.name, self.id, getattr(self, 'style_id', ''))
+        s = f"\n<{self.name} objid=\"{self.id}\" blockstyle=\"{getattr(self, 'style_id', '')}\" "
         if hasattr(self, 'textstyle_id'):
-            s += 'textstyle="%d" '%(self.textstyle_id,)
+            s += f'textstyle="{self.textstyle_id}" '
         for attr in self.attrs:
-            s += '%s="%s" '%(attr, self.attrs[attr])
+            s += f'{attr}="{self.attrs[attr]}" '
         if self.name != 'ImageBlock':
             s = s.rstrip()+'>\n'
             s += str(self.content)
-            s += '</%s>\n'%(self.name,)
+            s += f'</{self.name}>\n'
             return s
         return s.rstrip() + ' />\n'
 
     def to_html(self):
         if self.name == 'TextBlock':
-            return '<div class="block%s text%s">%s</div>'%(self.style_id, self.textstyle_id, self.content.to_html())
+            return f'<div class="block{self.style_id} text{self.textstyle_id}">{self.content.to_html()}</div>'
         return ''
 
 
@@ -637,9 +635,9 @@ class Text(LRFStream):
     tag_map.update(TextAttr.tag_map)
     tag_map.update(LRFStream.tag_map)
 
-    style = property(fget=lambda self : self._document.objects[self.style_id])
+    style = property(fget=lambda self: self._document.objects[self.style_id])
 
-    text_map = {0x22: '"', 0x26: '&amp;', 0x27: '\'', 0x3c: '&lt;', 0x3e: '&gt;'}
+    text_map = {0x22: '"', 0x26: '&amp;', 0x27: "'", 0x3c: '&lt;', 0x3e: '&gt;'}
     entity_pattern = re.compile(r'&amp;(\S+?);')
 
     text_tags = {
@@ -688,9 +686,9 @@ class Text(LRFStream):
             self.self_closing = self_closing
 
         def __str__(self):
-            s = '<%s '%(self.name,)
+            s = f'<{self.name} '
             for name, val in self.attrs.items():
-                s += '%s="%s" '%(name, val)
+                s += f'{name}="{val}" '
             return s.rstrip() + (' />' if self.self_closing else '>')
 
         def to_html(self):
@@ -708,10 +706,10 @@ class Text(LRFStream):
     lineposition_map = {1:'before', 2:'after'}
 
     def add_text(self, text):
-        s = str(text, "utf-16-le")
+        s = str(text, 'utf-16-le')
         if s:
             s = s.translate(self.text_map)
-            self.content.append(self.entity_pattern.sub(entity_to_unicode, s))
+            self.content.append(self.entity_pattern.sub(entity_to_unicode_in_python, s))
 
     def end_container(self, tag, stream):
         self.content.append(None)
@@ -788,7 +786,7 @@ class Text(LRFStream):
                                         self_closing=True))
 
     def plot(self, tag, stream):
-        xsize, ysize, refobj, adjustment = struct.unpack("<HHII", tag.contents)
+        xsize, ysize, refobj, adjustment = struct.unpack('<HHII', tag.contents)
         plot = self.__class__.TextTag('Plot',
             {'xsize': xsize, 'ysize': ysize, 'refobj':refobj,
              'adjustment':self.adjustment_map[adjustment]}, self_closing=True)
@@ -829,7 +827,7 @@ class Text(LRFStream):
                         return pos-1
                     return find_first_tag(pos+1)
 
-                except:
+                except Exception:
                     return find_first_tag(pos+1)
 
             start_pos = stream.tell()
@@ -878,7 +876,7 @@ class Text(LRFStream):
             elif c is None:
                 if open_containers:
                     p = open_containers.pop()
-                    s += '</%s>'%(p.name,)
+                    s += f'</{p.name}>'
             else:
                 s += str(c)
                 if not c.self_closing:
@@ -886,9 +884,9 @@ class Text(LRFStream):
 
         if len(open_containers) > 0:
             if len(open_containers) == 1:
-                s += '</%s>'%(open_containers[0].name,)
+                s += f'</{open_containers[0].name}>'
             else:
-                raise LRFParseError('Malformed text stream %s'%([i.name for i in open_containers if isinstance(i, Text.TextTag)],))
+                raise LRFParseError(f'Malformed text stream {[i.name for i in open_containers if isinstance(i, Text.TextTag)]}')
         return s
 
     def to_html(self):
@@ -912,7 +910,7 @@ class Text(LRFStream):
                         open_containers.append(c)
 
         if len(open_containers) > 0:
-            raise LRFParseError('Malformed text stream %s'%([i.name for i in open_containers if isinstance(i, Text.TextTag)],))
+            raise LRFParseError(f'Malformed text stream {[i.name for i in open_containers if isinstance(i, Text.TextTag)]}')
         return s
 
 
@@ -925,17 +923,18 @@ class Image(LRFObject):
       }
 
     def parse_image_rect(self, tag, f):
-        self.x0, self.y0, self.x1, self.y1 = struct.unpack("<HHHH", tag.contents)
+        self.x0, self.y0, self.x1, self.y1 = struct.unpack('<HHHH', tag.contents)
 
     def parse_image_size(self, tag, f):
-        self.xsize, self.ysize = struct.unpack("<HH", tag.contents)
+        self.xsize, self.ysize = struct.unpack('<HH', tag.contents)
 
-    encoding = property(fget=lambda self : self._document.objects[self.refstream].encoding)
-    data = property(fget=lambda self : self._document.objects[self.refstream].stream)
+    encoding = property(fget=lambda self: self._document.objects[self.refstream].encoding)
+    data = property(fget=lambda self: self._document.objects[self.refstream].stream)
 
     def __str__(self):
-        return '<Image objid="%s" x0="%d" y0="%d" x1="%d" y1="%d" xsize="%d" ysize="%d" refstream="%d" />\n'%\
-        (self.id, self.x0, self.y0, self.x1, self.y1, self.xsize, self.ysize, self.refstream)
+        return (
+            f'<Image objid="{self.id}" x0="{self.x0}" y0="{self.y0}" x1="{self.x1}" y1="{self.y1}"'
+            f' xsize="{self.xsize}" ysize="{self.ysize}" refstream="{self.refstream}" />\n')
 
 
 class PutObj(EmptyPageElement):
@@ -945,7 +944,7 @@ class PutObj(EmptyPageElement):
         self.object = objects[refobj]
 
     def __str__(self):
-        return '<PutObj x1="%d" y1="%d" refobj="%d" />'%(self.x1, self.y1, self.refobj)
+        return f'<PutObj x1="{self.x1}" y1="{self.y1}" refobj="{self.refobj}" />'
 
 
 class Canvas(LRFStream):
@@ -953,7 +952,7 @@ class Canvas(LRFStream):
         0xF551: ['canvaswidth', 'W'],
         0xF552: ['canvasheight', 'W'],
         0xF5DA: ['', 'parse_waits'],
-        0xF533: ['blockrule', 'W', {0x44: "block-fixed", 0x22: "block-adjustable"}],
+        0xF533: ['blockrule', 'W', {0x44: 'block-fixed', 0x22: 'block-adjustable'}],
         0xF534: ['bgcolor', 'D', Color],
         0xF535: ['layout', 'W', {0x41: 'TbRl', 0x34: 'LrTb'}],
         0xF536: ['framewidth', 'W'],
@@ -982,18 +981,18 @@ class Canvas(LRFStream):
             try:
                 self._contents.append(
                     PutObj(self._document.objects,
-                        *struct.unpack("<HHI", tag.contents)))
+                        *struct.unpack('<HHI', tag.contents)))
             except struct.error:
                 print('Canvas object has errors, skipping.')
 
     def __str__(self):
-        s = '\n<%s objid="%s" '%(self.__class__.__name__, self.id,)
+        s = f'\n<{self.__class__.__name__} objid="{self.id}" '
         for attr in self.attrs:
-            s += '%s="%s" '%(attr, self.attrs[attr])
+            s += f'{attr}="{self.attrs[attr]}" '
         s = s.rstrip() + '>\n'
         for po in self:
             s += str(po) + '\n'
-        s += '</%s>\n'%(self.__class__.__name__,)
+        s += f'</{self.__class__.__name__}>\n'
         return s
 
     def __iter__(self):
@@ -1020,7 +1019,7 @@ class ImageStream(LRFStream):
 
     tag_map.update(LRFStream.tag_map)
 
-    encoding = property(fget=lambda self : self.imgext[self.stream_flags & 0xFF].upper())
+    encoding = property(fget=lambda self: self.imgext[self.stream_flags & 0xFF].upper())
 
     def end_stream(self, *args):
         LRFStream.end_stream(self, *args)
@@ -1029,8 +1028,7 @@ class ImageStream(LRFStream):
             self._document.image_map[self.id] = self
 
     def __str__(self):
-        return '<ImageStream objid="%s" encoding="%s" file="%s" />\n'%\
-            (self.id, self.encoding, self.file)
+        return f'<ImageStream objid="{self.id}" encoding="{self.encoding}" file="{self.file}" />\n'
 
 
 class Import(LRFStream):
@@ -1086,7 +1084,7 @@ class Button(LRFObject):
         self.actions[self.button_type] = []
 
     def parse_jump_to(self, tag, f):
-        self.actions[self.button_type].append((1, struct.unpack("<II", tag.contents)))
+        self.actions[self.button_type].append((1, struct.unpack('<II', tag.contents)))
 
     def parse_send_message(self, tag, f):
         params = (tag.word, Tag.string_parser(f), Tag.string_parser(f))
@@ -1099,30 +1097,30 @@ class Button(LRFObject):
         self.actions[self.button_type].append((4,))
 
     def parse_run(self, tag, f):
-        self.actions[self.button_type].append((5, struct.unpack("<HI", tag.contents)))
+        self.actions[self.button_type].append((5, struct.unpack('<HI', tag.contents)))
 
     def jump_action(self, button_type):
         for i in self.actions[button_type]:
             if i[0] == 1:
                 return i[1:][0]
-        return (None, None)
+        return None, None
 
     def __str__(self):
-        s = '<Button objid="%s">\n'%(self.id,)
+        s = f'<Button objid="{self.id}">\n'
         if self.button_flags & 0x10 != 0:
             s += '<PushButton '
             if 2 in self.refimage:
-                s += 'refimage="%s" '%(self.refimage[2],)
+                s += f'refimage="{self.refimage[2]}" '
             s = s.rstrip() + '>\n'
-            s += '<JumpTo refpage="%s" refobj="%s" />\n'% self.jump_action(2)
+            s += '<JumpTo refpage="{}" refobj="{}" />\n'.format(*self.jump_action(2))
             s += '</PushButton>\n'
         else:
             raise LRFParseError('Unsupported button type')
         s += '</Button>\n'
         return s
 
-    refpage = property(fget=lambda self : self.jump_action(2)[0])
-    refobj = property(fget=lambda self : self.jump_action(2)[1])
+    refpage = property(fget=lambda self: self.jump_action(2)[0])
+    refobj = property(fget=lambda self: self.jump_action(2)[1])
 
 
 class Window(LRFObject):
@@ -1155,8 +1153,7 @@ class Font(LRFStream):
         self.file = self.fontfacename + '.ttf'
 
     def __unicode__(self):
-        s = '<RegistFont objid="%s" fontfilename="%s" fontname="%s" encoding="TTF" file="%s" />\n'%\
-            (self.id, self.fontfilename, self.fontfacename, self.file)
+        s = f'<RegistFont objid="{self.id}" fontfilename="{self.fontfilename}" fontname="{self.fontfacename}" encoding="TTF" file="{self.file}" />\n'
         return s
 
 
@@ -1172,7 +1169,7 @@ class BookAttr(StyleObject, LRFObject):
       }
     tag_map.update(ruby_tags)
     tag_map.update(LRFObject.tag_map)
-    binding_map = {1: 'Lr', 16 : 'Rl'}
+    binding_map = {1: 'Lr', 16: 'Rl'}
 
     def __init__(self, document, stream, id, scramble_key, boundary):
         self.font_link_list = []
@@ -1182,11 +1179,11 @@ class BookAttr(StyleObject, LRFObject):
         self.font_link_list.append(tag.dword)
 
     def __str__(self):
-        s = '<BookStyle objid="%s" stylelabel="%s">\n'%(self.id, self.id)
-        s += '<SetDefault %s />\n'%(self._tags_to_xml(),)
+        s = f'<BookStyle objid="{self.id}" stylelabel="{self.id}">\n'
+        s += f'<SetDefault {self._tags_to_xml()} />\n'
         doc = self._document
-        s += '<BookSetting bindingdirection="%s" dpi="%s" screenwidth="%s" screenheight="%s" colordepth="%s" />\n'%\
-        (self.binding_map[doc.binding], doc.dpi, doc.width, doc.height, doc.color_depth)
+        s += f'<BookSetting bindingdirection="{self.binding_map[doc.binding]}" dpi="{doc.dpi}" screenwidth="{doc.width}"'
+        s += f' screenheight="{doc.height}" colordepth="{doc.color_depth}" />\n'
         for font in self._document.font_map.values():
             s += str(font)
         s += '</BookStyle>\n'
@@ -1203,20 +1200,20 @@ class TocLabel:
         self.refpage, self.refobject, self.label = refpage, refobject, label
 
     def __str__(self):
-        return '<TocLabel refpage="%s" refobj="%s">%s</TocLabel>\n'%(self.refpage, self.refobject, self.label)
+        return f'<TocLabel refpage="{self.refpage}" refobj="{self.refobject}">{self.label}</TocLabel>\n'
 
 
 class TOCObject(LRFStream):
 
     def initialize(self):
         stream = io.BytesIO(self.stream or b'')
-        c = struct.unpack("<H", stream.read(2))[0]
+        c = struct.unpack('<H', stream.read(2))[0]
         stream.seek(4*(c+1))
         self._contents = []
         while c > 0:
-            refpage = struct.unpack("<I", stream.read(4))[0]
-            refobj  = struct.unpack("<I", stream.read(4))[0]
-            cnt = struct.unpack("<H", stream.read(2))[0]
+            refpage = struct.unpack('<I', stream.read(4))[0]
+            refobj  = struct.unpack('<I', stream.read(4))[0]
+            cnt = struct.unpack('<H', stream.read(2))[0]
             raw = stream.read(cnt)
             label = raw.decode('utf_16_le')
             self._contents.append(TocLabel(refpage, refobj, label))
@@ -1272,8 +1269,8 @@ def get_object(document, stream, id, offset, size, scramble_key):
     start_tag = Tag(stream)
     if start_tag.id != 0xF500:
         raise LRFParseError('Bad object start')
-    obj_id, obj_type = struct.unpack("<IH", start_tag.contents)
+    obj_id, obj_type = struct.unpack('<IH', start_tag.contents)
     if obj_type < len(object_map) and object_map[obj_type] is not None:
         return object_map[obj_type](document, stream, obj_id, scramble_key, offset+size-Tag.tags[0][0])
 
-    raise LRFParseError("Unknown object type: %02X!" % obj_type)
+    raise LRFParseError(f'Unknown object type: {obj_type:02X}!')
