@@ -4,7 +4,7 @@
 __license__ = 'GPL v3'
 __copyright__ = '2014, Kovid Goyal <kovid at kovidgoyal.net>'
 
-from struct import unpack_from, error
+from struct import error, unpack_from
 
 from calibre.utils.imghdr import what
 
@@ -44,5 +44,3 @@ class Container:
             if imgtype != 'unknown':
                 return data, imgtype
         return None, None
-
-
