@@ -57,6 +57,19 @@ class KepubifyTests(BaseTest):
 div#book-inner {{ margin-top: 0; margin-bottom: 0; }}</style><script type="text/javascript" src="{KOBO_JS_NAME}"/></head>\
 <body><div id="book-columns"><div id="book-inner">'''
         suffix =  '</div></div></body></html>'
+
+        def perform(src, expected, prefer_justification):
+            opts = Options(remove_widows_and_orphans=True, remove_at_page_rules=True, prefer_justification=prefer_justification)
+            root = kepubify_html_data(src, KOBO_JS_NAME, opts)
+            actual = serialize_html(root).decode('utf-8')
+            actual = actual[len(prefix):-len(suffix)]
+            self.assertEqual(expected, actual, f'\n\nText:\n{src}\n\nExpected:\n{expected}\n\nActual:\n{actual}')
+            expected = serialize_html(parse(src)).decode('utf-8')
+            opts = opts._replace(for_removal=True)
+            kepubify_parsed_html(root, KOBO_JS_NAME, opts)
+            actual = serialize_html(root).decode('utf-8')
+            self.assertEqual(expected, actual, f'\n\nText:\n{src}\n\nExpected:\n{expected}\n\nActual:\n{actual}')
+
         for src, expected in {
             # basics
             '<p>one</p>  <p>\xa0</p><p>\xa0<i>a</i></p>':
@@ -64,7 +77,7 @@ div#book-inner {{ margin-top: 0; margin-bottom: 0; }}</style><script type="text/
             '<p>&#160;<i><span class="koboSpan" id="kobo.3.1">a</span></i></p>',
 
             '<p>Simple sentences. In a single paragraph.'
-            '<p>A sentence <i>with <b>nested</b>, tailed</i> formatting. Another.':
+            '<p>A sentence <i>with <b>nested</b>, tailed</i> formatting. Another.': (
 
             '<p><span class="koboSpan" id="kobo.1.1">Simple sentences. </span><span class="koboSpan" id="kobo.1.2">In a single paragraph.</span></p>'
             '<p><span class="koboSpan" id="kobo.2.1">A sentence </span><i><span class="koboSpan" id="kobo.2.2">with </span>'
@@ -72,6 +85,14 @@ div#book-inner {{ margin-top: 0; margin-bottom: 0; }}</style><script type="text/
             '<span class="koboSpan" id="kobo.2.5"> formatting. </span>'
             '<span class="koboSpan" id="kobo.2.6">Another.</span></p>',
 
+            # with prefer_justification
+            '<p><span class="koboSpan" id="kobo.1.1">Simple sentences.</span> <span class="koboSpan" id="kobo.1.2">In a single paragraph.</span></p>'
+            '<p><span class="koboSpan" id="kobo.2.1">A sentence</span> <i><span class="koboSpan" id="kobo.2.2">with</span>'
+            ' <b><span class="koboSpan" id="kobo.2.3">nested</span></b><span class="koboSpan" id="kobo.2.4">, tailed</span></i> '
+            '<span class="koboSpan" id="kobo.2.5">formatting.</span> '
+            '<span class="koboSpan" id="kobo.2.6">Another.</span></p>',
+            ),
+
             # img tags
             '<p>An image<img src="x">with tail<img src="b"><i>without':
             '<p><span class="koboSpan" id="kobo.1.1">An image</span><span class="koboSpan" id="kobo.2.1"><img src="x"/></span>'
@@ -85,22 +106,35 @@ div#book-inner {{ margin-top: 0; margin-bottom: 0; }}</style><script type="text/
             '<p><span class="koboSpan" id="kobo.2.1">A comment</span><!-- xx --><i><span class="koboSpan" id="kobo.2.2">without tail</span></i></p>',
 
             # nested block tags
-            '<div>A div<div> nested.<ul><li>A list<p> with nested block</p> tail1</li> tail2</ul> tail3':
+            '<div>A div<div> nested.<ul><li>A list<p> with nested block</p> tail1</li> tail2</ul> tail3': (
             '<div><span class="koboSpan" id="kobo.1.1">A div</span><div><span class="koboSpan" id="kobo.1.2"> nested.</span>'
             '<ul><li><span class="koboSpan" id="kobo.2.1">A list</span><p><span class="koboSpan" id="kobo.3.1"> with nested block</span></p>'
             '<span class="koboSpan" id="kobo.3.2"> tail1</span></li><span class="koboSpan" id="kobo.3.3"> tail2</span></ul>'
             '<span class="koboSpan" id="kobo.3.4"> tail3</span></div></div>',
+            # with prefer_justification
+            '<div><span class="koboSpan" id="kobo.1.1">A div</span><div> <span class="koboSpan" id="kobo.1.2">nested.</span>'
+            '<ul><li><span class="koboSpan" id="kobo.2.1">A list</span><p> <span class="koboSpan" id="kobo.3.1">with nested block</span></p>'
+            ' <span class="koboSpan" id="kobo.3.2">tail1</span></li> <span class="koboSpan" id="kobo.3.3">tail2</span></ul>'
+            ' <span class="koboSpan" id="kobo.3.4">tail3</span></div></div>',
+            ),
 
             # skipped tags
-            '<div>Script: <script>a = 1</script> with tail':
+            '<div>Script: <script>a = 1</script> with tail': (
             '<div><span class="koboSpan" id="kobo.1.1">Script: </span><script>a = 1</script><span class="koboSpan" id="kobo.1.2"> with tail</span></div>',
-            '<div>Svg: <svg>mouse</svg><i> no tail':
+            '<div><span class="koboSpan" id="kobo.1.1">Script:</span> <script>a = 1</script> <span class="koboSpan" id="kobo.1.2">with tail</span></div>',
+            ),
+            '<div>Svg: <svg>mouse</svg><i> no tail': (
             '<div><span class="koboSpan" id="kobo.1.1">Svg: </span><svg xmlns="http://www.w3.org/2000/svg">mouse</svg>'
             '<i><span class="koboSpan" id="kobo.1.2"> no tail</span></i></div>',
+            '<div><span class="koboSpan" id="kobo.1.1">Svg:</span> <svg xmlns="http://www.w3.org/2000/svg">mouse</svg>'
+            '<i> <span class="koboSpan" id="kobo.1.2">no tail</span></i></div>',
+            ),
 
             # encoding quirks
-            '<p>A\xa0nbsp;&nbsp;':
+            '<p>A\xa0nbsp;&nbsp;': (
             '<p><span class="koboSpan" id="kobo.1.1">A&#160;nbsp;&#160;</span></p>',
+            '<p><span class="koboSpan" id="kobo.1.1">A&#160;nbsp;</span>&#160;</p>',
+            ),
             '<div><script>1 < 2 & 3</script>':  # escaping with cdata note that kepubify doesn't do this
             '<div><script><![CDATA[1 < 2 & 3]]></script></div>',
 
@@ -110,13 +144,7 @@ div#book-inner {{ margin-top: 0; margin-bottom: 0; }}</style><script type="text/
             f'div {{\n  -{CSS_COMMENT_COOKIE}-widows: 12;\n  color: red;\n}}</style>'
             '<span class="koboSpan" id="kobo.1.1">Some</span></div>'
         }.items():
-            opts = Options()._replace(remove_widows_and_orphans=True, remove_at_page_rules=True)
-            root = kepubify_html_data(src, KOBO_JS_NAME, opts)
-            actual = serialize_html(root).decode('utf-8')
-            actual = actual[len(prefix):-len(suffix)]
-            self.assertEqual(expected, actual)
-            expected = serialize_html(parse(src)).decode('utf-8')
-            opts = opts._replace(for_removal=True)
-            kepubify_parsed_html(root, KOBO_JS_NAME, opts)
-            actual = serialize_html(root).decode('utf-8')
-            self.assertEqual(expected, actual)
+            if isinstance(expected, str):
+                expected = expected, expected
+            perform(src, expected[0], False)
+            perform(src, expected[1], True)
