@@ -186,7 +186,7 @@ class TextileMLizer(OEB2HTML):
         if 'margin-left' in style.cssdict() and style['margin-left'] != 'auto':
             left_margin_pts = unit_convert(style['margin-left'], style.width, style.fontSize, stylizer.profile.dpi)
         left = add(left_margin_pts, left_padding_pts)
-        emleft = min(int(round(left / stylizer.profile.fbase)), self.MAX_EM)
+        emleft = min(round(left / stylizer.profile.fbase), self.MAX_EM)
         if emleft >= 1:
             txt += '(' * emleft
         right_padding_pts = 0
@@ -196,7 +196,7 @@ class TextileMLizer(OEB2HTML):
         if 'margin-right' in style.cssdict() and style['margin-right'] != 'auto':
             right_margin_pts = unit_convert(style['margin-right'], style.width, style.fontSize, stylizer.profile.dpi)
         right = add(right_margin_pts, right_padding_pts)
-        emright = min(int(round(right / stylizer.profile.fbase)), self.MAX_EM)
+        emright = min(round(right / stylizer.profile.fbase), self.MAX_EM)
         if emright >= 1:
             txt += ')' * emright
 
@@ -492,7 +492,7 @@ class TextileMLizer(OEB2HTML):
 
         # Soft scene breaks.
         if 'margin-bottom' in style.cssdict() and style['margin-bottom'] != 'auto':
-            ems = min(int(round((float(style.marginBottom) / style.fontSize) - 1)), self.MAX_EM)
+            ems = min(round((float(style.marginBottom) / style.fontSize) - 1), self.MAX_EM)
             if ems >= 1:
                 text.append('\n\n\xa0' * ems)
 
