@@ -24,7 +24,7 @@ d['editor_show_char_under_cursor'] = True
 d['replace_entities_as_typed'] = True
 d['preview_refresh_time'] = 2
 d['choose_tweak_fmt'] = True
-d['tweak_fmt_order'] = ['EPUB', 'AZW3']
+d['tweak_fmt_order'] = ['EPUB', 'KEPUB', 'AZW3']
 d['update_metadata_from_calibre'] = True
 d['nestable_dock_widgets'] = False
 d['dock_top_left'] = 'horizontal'
