@@ -7,6 +7,7 @@ __copyright__ = '2015, Kovid Goyal <kovid at kovidgoyal.net>'
 import os
 import textwrap
 import time
+import unicodedata
 from collections import defaultdict
 from contextlib import suppress
 from csv import writer as csv_writer
@@ -906,7 +907,8 @@ class CharsWidget(QWidget):
     def __call__(self, data):
         self.model(data)
         self.chars.resize_rows()
-        self.summary.setText(''.join(self.model.all_chars))
+        c = unicodedata.category
+        self.summary.setText(''.join(sorted(ch for ch in self.model.all_chars if c(ch) not in ('Zs', 'Cc'))))
         self.filter_edit.clear()
 
     def double_clicked(self, index):
@@ -1016,12 +1018,14 @@ class CSSRulesModel(QAbstractItemModel):
         return 1
 
     def data(self, index, role=Qt.ItemDataRole.DisplayRole):
+        if index.column() != 0:
+            return
         if role == SORT_ROLE:
             entry = self.index_to_entry(index)
             if isinstance(entry, CSSEntry):
-                return entry.count if self.sort_on_count else entry.sort_key
+                return entry.count if self.sort_on_count else QByteArray(entry.sort_key)
             if isinstance(entry, CSSFileMatch):
-                return len(entry.locations) if self.sort_on_count else entry.sort_key
+                return len(entry.locations) if self.sort_on_count else QByteArray(entry.sort_key)
             if isinstance(entry, MatchLocation):
                 return entry.sourceline
         elif role == Qt.ItemDataRole.DisplayRole:
@@ -1097,6 +1101,7 @@ class CSSWidget(QWidget):
         e.setClearButtonEnabled(True)
         self.model = m = self.MODEL(self)
         self.proxy = p = self.PROXY(self)
+        m.sort_on_count = self.read_state('sort-on-counts', True)
         p.setSourceModel(m)
         self.view = f = QTreeView(self)
         f.setAlternatingRowColors(True)
@@ -1109,10 +1114,10 @@ class CSSWidget(QWidget):
         l.addLayout(h)
         h.addWidget(QLabel(_('Sort by:')))
         self.counts_button = b = QRadioButton(_('&Counts'), self)
-        b.setChecked(self.read_state('sort-on-counts', True))
+        b.setChecked(m.sort_on_count)
         h.addWidget(b)
         self.name_button = b = QRadioButton(_('&Name'), self)
-        b.setChecked(not self.read_state('sort-on-counts', True))
+        b.setChecked(not m.sort_on_count)
         h.addWidget(b)
         b.toggled.connect(self.resort)
         h.addStrut(20)
@@ -1239,9 +1244,9 @@ class ClassesModel(CSSRulesModel):
         if role == SORT_ROLE:
             entry = self.index_to_entry(index)
             if isinstance(entry, ClassEntry):
-                return entry.num_of_matches if self.sort_on_count else entry.sort_key
+                return entry.num_of_matches if self.sort_on_count else QByteArray(entry.sort_key)
             if isinstance(entry, ClassFileMatch):
-                return len(entry.class_elements) if self.sort_on_count else entry.sort_key
+                return len(entry.class_elements) if self.sort_on_count else QByteArray(entry.sort_key)
             if isinstance(entry, ClassElement):
                 return entry.line_number
             if isinstance(entry, CSSRule):
