@@ -25,8 +25,7 @@ class CFF:
         (self.major_version, self.minor_version, self.header_size,
                 self.offset_size) = unpack_from(b'>4B', raw)
         if (self.major_version, self.minor_version) != (1, 0):
-            raise UnsupportedFont('The CFF table has unknown version: '
-                    '(%d, %d)'%(self.major_version, self.minor_version))
+            raise UnsupportedFont(f'The CFF table has unknown version: ({self.major_version}, {self.minor_version})')
         offset = self.header_size
 
         # Read Names Index
@@ -62,7 +61,7 @@ class CFF:
         cs_type = self.top_dict.safe_get('CharstringType')
         if cs_type != 2:
             raise UnsupportedFont('This font has unsupported CharstringType: '
-                    '%s'%cs_type)
+                    f'{cs_type}')
         self.char_strings = CharStringsIndex(raw, offset)
         self.num_glyphs = len(self.char_strings)
 
@@ -105,7 +104,7 @@ class Index(list):
                             for i in range(offset, offset+3*(count+1), 3)]
             else:
                 fmt = {1:'B', 2:'H', 4:'L'}[self.offset_size]
-                fmt = ('>%d%s'%(count+1, fmt)).encode('ascii')
+                fmt = f'>{count + 1}{fmt}'.encode('ascii')
                 offsets = unpack_from(fmt, raw, offset)
             offset += self.offset_size * (count+1) - 1
 
@@ -133,7 +132,7 @@ class Charset(list):
         super().__init__()
         self.standard_charset = offset if offset in {0, 1, 2} else None
         if is_CID and self.standard_charset is not None:
-            raise ValueError("CID font must not use a standard charset")
+            raise ValueError('CID font must not use a standard charset')
         if self.standard_charset is None:
             self.append(b'.notdef')
             fmt = unpack_from(b'>B', raw, offset)[0]
@@ -141,15 +140,14 @@ class Charset(list):
             f = {0:self.parse_fmt0, 1:self.parse_fmt1,
                 2:partial(self.parse_fmt1, is_two_byte=True)}.get(fmt, None)
             if f is None:
-                raise UnsupportedFont('This font uses unsupported charset '
-                        'table format: %d'%fmt)
+                raise UnsupportedFont(f'This font uses unsupported charset table format: {fmt}')
             f(raw, offset, strings, num_glyphs, is_CID)
 
     def parse_fmt0(self, raw, offset, strings, num_glyphs, is_CID):
-        fmt = ('>%dH'%(num_glyphs-1)).encode('ascii')
+        fmt = f'>{num_glyphs - 1}H'.encode('ascii')
         ids = unpack_from(fmt, raw, offset)
         if is_CID:
-            ids = ('cid%05d'%x for x in ids)
+            ids = (f'cid{x:05}' for x in ids)
         else:
             ids = (strings[x] for x in ids)
         self.extend(ids)
@@ -163,7 +161,7 @@ class Charset(list):
             first, nleft = unpack_from(fmt, raw, offset)
             offset += sz
             count += nleft + 1
-            self.extend('cid%05d'%x if is_CID else strings[x] for x in
+            self.extend(f'cid{x:05}' if is_CID else strings[x] for x in
                     range(first, first + nleft+1))
 
     def lookup(self, glyph_id):
